jpountz opened a new pull request #322: URL: https://github.com/apache/lucene/pull/322
Even though it was not the driver for the slowdown, in LUCENE-10125 we identified that the move to PFOR had slowed down indexing significantly for fields indexed with indexOptions=DOCS. This patch gets some of the peformance back by using the `LongHeap` that we introduced for vectors instead of sorting the same array over and over again. On the NYC Taxis benchmark, I observed ~8% faster merges of postings with this change. -- This is an automated message from the Apache Git Service. To respond to the message, please log on to GitHub and use the URL above to go to the specific comment. To unsubscribe, e-mail: [email protected] For queries about this service, please contact Infrastructure at: [email protected] --------------------------------------------------------------------- To unsubscribe, e-mail: [email protected] For additional commands, e-mail: [email protected]
